[OB] Fix some comments to say minus_one_ptid instead of PID == -1

Message ID m3egu3n6a9.fsf@sspiff.org
State New, archived
Headers

Commit Message

Doug Evans Oct. 19, 2014, 8:39 p.m. UTC
  Hi.

Committed as obvious.

2014-10-19  Doug Evans  <xdje42@gmail.com>

	* gdbthread.h (set_running): Fix comment.
	(set_executing, finish_thread_state): Fix comment.
  

Patch

diff --git a/gdb/gdbthread.h b/gdb/gdbthread.h
index 937bd55..fb47bae 100644
--- a/gdb/gdbthread.h
+++ b/gdb/gdbthread.h
@@ -368,7 +368,7 @@  extern int thread_count (void);
 extern void switch_to_thread (ptid_t ptid);
 
 /* Marks thread PTID is running, or stopped. 
-   If ptid_get_pid (PTID) is -1, marks all threads.  */
+   If PTID is minus_one_ptid, marks all threads.  */
 extern void set_running (ptid_t ptid, int running);
 
 /* Marks or clears thread(s) PTID as having been requested to stop.
@@ -403,7 +403,7 @@  extern int is_exited (ptid_t ptid);
 /* In the frontend's perpective, is this thread stopped?  */
 extern int is_stopped (ptid_t ptid);
 
 /* Marks thread PTID as executing, or not.  If ptid_get_pid (PTID) is -1,
    marks all threads.
 
    Note that this is different from the running state.  See the
@@ -424,7 +424,7 @@  extern int threads_are_executing (void);
    "executing"     -> "running"
    "exited"        -> "exited"
 
-   If ptid_get_pid (PTID) is -1, go over all threads.
+   If PTID is minus_one_ptid, go over all threads.
 
    Notifications are only emitted if the thread state did change.  */
 extern void finish_thread_stateg (ptid_t ptid);
@@ -403,7 +403,7 @@  extern int is_exited (ptid_t ptid);
 extern int is_stopped (ptid_t ptid);
 
-/* Marks thread PTID as executing, or not.  If ptid_get_pid (PTID) is -1,
+/* Marks thread PTID as executing, or not.  If PTID is minus_one_ptid,
    marks all threads.
 